@@ -1,5 +1,5 @@
 package Mongoose;
-$Mongoose::VERSION = '0.36';
+$Mongoose::VERSION = '0.37';
 use MooseX::Singleton;
 use Class::MOP;
 use MongoDB;
@@ -8,13 +8,13 @@ use version;
 
 with 'Mongoose::Role::Naming';
 
-has '_db' => (
+has _db => (
     is      => 'rw',
     isa     => 'HashRef',
     default => sub {{}},
 );
 
-has '_client' => (
+has _client => (
     is      => 'rw',
     isa     => "HashRef",
     lazy    => 1,
@@ -22,7 +22,7 @@ has '_client' => (
     clearer => 'disconnect'
 );
 
-has '_args' => (
+has _args => (
     is      => 'rw',
     isa     => 'HashRef',
     default => sub{{}}
@@ -33,6 +33,18 @@ has _mongodb_v1 => (
     default => sub { version->parse($MongoDB::VERSION) > '0.900' }
 );
 
+has _alias => ( # keep track of aliased() document classes.
+    is      => 'rw',
+    isa     => 'HashRef',
+    default => sub{{}}
+);
+
+has _config => ( # Store document classes configuration
+    is      => 'rw',
+    isa     => 'HashRef',
+    default => sub{{}}
+);
+
 sub db {
     my $self = shift;
     my %p    = @_ == 1 ? (db_name=>shift) : @_;
@@ -42,6 +54,19 @@ sub db {
     return $self->connect($name) if $now || defined wantarray;
 }
 
+sub class_config {
+    my ( $self, $class_name, $config ) = @_;
+
+    # Set
+    return $self->_config->{$class_name} = $config if $config;
+
+    # Get
+    my $class = $self->aliased(ref $class_name || $class_name);
+    confess "Document class '$class' is not registered. Registered classes are: ".
+            join(', ', keys %{$self->_config}) unless exists $self->_config->{$class};
+    $self->_config->{$class};
+}
+
 # setup db config and class to db mapping if class exists.
 sub _add_args {
     my ( $self, $args ) = @_;
@@ -90,9 +115,10 @@ sub connection {
 
 sub load_schema {
     my ( $self, %args ) = @_;
-    require Module::Pluggable;
-    my $shorten = delete $args{shorten};
+    my $shorten     = delete $args{shorten};
     my $search_path = delete $args{search_path};
+
+    require Module::Pluggable;
     Module::Pluggable->import( search_path => $search_path );
     for my $module ( $self->plugins ) {
         eval "require $module";
@@ -103,10 +129,17 @@ sub load_schema {
             *{ $short_name . "::" } = \*{ $module . "::" };
             Class::MOP::store_metaclass_by_name( $short_name, $module->meta );
             Class::MOP::weaken_metaclass( $short_name );
+            $self->aliased($short_name => $module);
         }
     }
 }
 
+sub aliased {
+    my ( $self, $alias, $class ) = @_;
+    $self->_alias->{$alias} = $class if $class;
+    exists $self->_alias->{$alias} ? $self->_alias->{$alias} : $alias;
+}
+
 1;
 
 =head1 NAME
@@ -192,7 +225,7 @@ using the MongoDB driver in a forked environment (ie. with a
 prefork appserver like Starman, Hypnotoad or Catalyst's
 HTTP::Prefork).
 
-If you prefer to connect while setting the connection string, 
+If you prefer to connect while setting the connection string,
 use one of these options:
 
     Mongoose->db( db_name=>'mydb', -now=>1 );  # connect now
@@ -206,7 +239,7 @@ use one of these options:
     Mongoose->db( 'mydb' );
     Mongoose->connect;
 
-You can separate your classes storage on multiple hosts/databases 
+You can separate your classes storage on multiple hosts/databases
 by calling db() several times:
 
     # Default host/database (connect now!)
@@ -231,8 +264,8 @@ Connects to Mongo using the connection arguments passed to the C<db> method.
 Uses L<Module::Pluggable> to C<require> all modules under a given search path
 or search dir.
 
-All arguments will be sent to Module::Pluggable's C<import>, except for 
-Mongoose specific ones. 
+All arguments will be sent to Module::Pluggable's C<import>, except for
+Mongoose specific ones.
 
     package main;
     use Mongoose;
@@ -264,6 +297,14 @@ Defaults to whatever MongoDB defaults.
 
 Unsets the Mongoose connection handler.
 
+=head2 class_config
+
+Keep track of document classes config solving aliasing indirection.
+
+=head2 aliased
+
+Keep track of aliasing classes. Useful to retrieve full document class from a shortened one.
+
 =head1 COLLECTION NAMING
 
 By default, Mongoose composes the Mongo collection name from your package name
