@@ -1,5 +1,5 @@
 package Mongoose::Engine::V1;
-$Mongoose::Engine::V1::VERSION = '0.36';
+$Mongoose::Engine::V1::VERSION = '0.37';
 use Moose::Role;
 
 use Carp;
@@ -22,7 +22,7 @@ sub collapse {
         return undef unless defined $class && $ref_id;
         return undef if $self->_id && $self->_id eq $ref_id; # prevent self references?
         return MongoDB::DBRef->new(
-            ref => $class->meta->{mongoose_config}{collection_name},
+            ref => Mongoose->class_config($class)->{collection_name},
             id  => $ref_id
         );
     }
@@ -64,7 +64,7 @@ sub _collapse {
         if ( ref $value eq 'HASH' && defined ( my $ref_id = $value->{_id} ) ) {
             # it has an id, so join ref it
             return MongoDB::DBRef->new(
-                ref => $class->meta->{mongoose_config}{collection_name},
+                ref => Mongoose->class_config($class)->{collection_name},
                 id  => $ref_id
             );
         }
@@ -86,7 +86,7 @@ sub _collapse {
             elsif ( $aryclass && $aryclass->does('Mongoose::Document') ) {
                 $item->_save( @scope, $self );
                 push @arr, MongoDB::DBRef->new(
-                    ref => $aryclass->meta->{mongoose_config}{collection_name},
+                    ref => Mongoose->class_config($aryclass)->{collection_name},
                     id  => $item->_id
                 );
             }
@@ -127,7 +127,7 @@ sub _unbless {
         elsif ( $class->does('Mongoose::Document') ) {
             $obj->_save( @scope, $self );
             $ret = MongoDB::DBRef->new(
-                ref => $class->meta->{mongoose_config}->{collection_name},
+                ref => Mongoose->class_config($class)->{collection_name},
                 id  => $obj->_id
             );
         }
@@ -147,11 +147,10 @@ sub _unbless {
 }
 
 sub expand {
-    my ($self,$doc,$fields,$scope)=@_;
-    my @later;
-    my $config     = $self->meta->{mongoose_config};
-    my $coll_name  = $config->{collection_name};
+    my ( $self, $doc, $fields, $scope ) = @_;
+    my $config     = Mongoose->class_config($self);
     my $class_main = ref $self || $self;
+    my @later;
 
     $scope = {} unless ref $scope eq 'HASH';
 
@@ -246,8 +245,9 @@ sub expand {
                 my $ref_arr = delete( $doc->{$name} );
                 my $ref_class = $type->type_parameter->class ;
                 $doc->{$name} = bless {
-                    class=>$class_main, field=>$name, parent=>$doc->{_id},
-                    with_class=>$ref_class, children=>$ref_arr, buffer=>{} } => $class;
+                    class => $class_main, field => $name, parent => $doc->{_id},
+                    with_class => $ref_class, children => $ref_arr, buffer => {}
+                } => $class;
             }
         }
         else { #non-moose
@@ -281,17 +281,14 @@ sub expand {
 sub _joint_fields {
     my $self = shift;
     return map { $_->name }
-        grep {
-            $_->type_constraint->isa('Mongoose::Join')
-        }
-        $self->meta->get_all_attributes ;
+        grep { $_->type_constraint->isa('Mongoose::Join') }
+        $self->meta->get_all_attributes;
 }
 
 sub fix_integrity {
     my ($self, @fields ) = @_;
     my $id = $self->_id;
-    @fields = $self->_joint_fields
-        unless scalar @fields;
+    @fields = $self->_joint_fields unless scalar @fields;
     for my $field ( @fields ) {
         my @children = $self->$field->_children_refs;
         $self->collection->update( { _id=>$id }, { '$set'=>{ $field=>\@children } } );
@@ -317,7 +314,7 @@ sub _save {
         return $id;
     }
     else {
-        if ( ref $self->meta->{mongoose_config}->{pk} ) {
+        if ( ref Mongoose->class_config($self)->{pk} ) {
             # if we have a pk and no _id, we must have a new
             # document, so we insert to allow the pk constraint
             # to ensure uniqueness; the 'safe' parameter ensures
@@ -391,7 +388,7 @@ sub collection {
     my $db = $self->db;
 
     # getter
-    my $config = $self->meta->{mongoose_config};
+    my $config = Mongoose->class_config($self);
     $new_collection or return $config->{collection}
         || ( $config->{collection} = $db->get_collection( $config->{collection_name} ) );
 
@@ -421,21 +418,18 @@ sub collection {
 
 sub _primary_key_query {
     my ( $self, $hash ) = @_;
-    my @keys  = @{ $self->meta->{mongoose_config}->{pk} || ['_id'] };
+    my @keys  = @{ Mongoose->class_config($self)->{pk} || ['_id'] };
     my @pairs = map { $_ => $self->{$_} } grep { $self->{$_} } @keys;
     # Query need to have all pk's
     return {@pairs} if @pairs == @keys * 2;
 }
 
-sub _collection_name {
-    my $self = shift;
-    return $self->meta->{mongoose_config}->{collection_name} ;
-}
+sub _collection_name { Mongoose->class_config(shift)->{collection_name} }
 
 sub find {
     my ($self,$query,$attrs) = @_;
     my $cursor = bless $self->collection->find($query,$attrs), 'Mongoose::Cursor';
-    $cursor->_collection_name( $self->meta->{mongoose_config}->{collection_name} );
+    $cursor->_collection_name( $self->_collection_name );
     $cursor->_class( ref $self || $self );
     return $cursor;
 }
@@ -443,7 +437,7 @@ sub find {
 sub query {
     my ($self,$query,$attrs) = @_;
     my $cursor = bless $self->collection->query($query,$attrs), 'Mongoose::Cursor';
-    $cursor->_collection_name( $self->meta->{mongoose_config}->{collection_name} );
+    $cursor->_collection_name( $self->_collection_name );
     $cursor->_class( ref $self || $self );
     return $cursor;
 }
@@ -452,7 +446,7 @@ sub find_one {
     my $self = shift;
 
     if( @_ == 1 && ( !ref($_[0]) || ref($_[0]) eq 'MongoDB::OID' ) ) {
-        my $query = { _id=> ref $_[0] ? $_[0] : MongoDB::OID->new( value=>$_[0] ) };
+        my $query = { _id=> ref $_[0] ? $_[0] : eval{MongoDB::OID->new( value=>$_[0] )}||$_[0] };
         if ( my $doc = $self->collection->find_one($query) ) {
             return $self->expand( $doc );
         }
